# Code for Figures S1 & S2 in
# Potential pension fund losses should not deter high-income countries from bold climate action
# https://doi.org/10.1016/j.joule.2023.05.023
# by Gregor Semieniuk, Lucas Chancel and Eulalie Saïsset

# load packages
library(tidyverse)
library(viridis)
options(scipen=999)

# set your working directory
setwd( "YOUR DIRECTORY" )

# load data for sensitivity plot
sens <- read_csv("figureS1+S2_data.csv")

sensm08 <-as.matrix(data.frame(sens[21:24,7],sens[5:8,7]))  
sensm12 <-as.matrix(data.frame(sens[21:24,7],sens[5:8,8]))  

pdf("figure_S1_zenodo.pdf",6,3.5)
layout(matrix(c(1,1,1,1,2,3,4,5),nrow = 4, ncol = 2, byrow = TRUE))
par(mar=c(2,3,.5,.1),oma=c(2,0,0,1),xpd=T)
barplot(as.matrix(sensm08),horiz = T,beside=F,col=viridis(4),xlim=c(0,350),names.arg = c("USA","Europe"))
mtext("a",font=2, side = 3, adj=-.06,lin=-0.4,cex=0.85)
#text(x=corn[1]+.01,y=corn[4]-.01,"a",font=2)
legend("topright",legend = c("Top 1% wealth owners","Next 9%","Middle 40%","Bottom 50%"),
       pch=15, lty=0, col=viridis(4)[4:1], bty="n",pt.cex=rep(2,4),x.intersp=0.9)
barplot(as.matrix(filter(sens,iso3 == "GBR")$med_quan08),horiz = T,beside=F,col=viridis(4),names.arg = c("UK"))
mtext("b",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
barplot(as.matrix(filter(sens,iso3 == "FRA")$med_quan08),horiz = T,beside=F,col=viridis(4),names.arg = c("France"))
mtext("c",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
barplot(as.matrix(filter(sens,iso3 == "DEU")$med_quan08),horiz = T,beside=F,col=viridis(4),names.arg = c("Germany"))
mtext("d",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
barplot(as.matrix(filter(sens,iso3 == "ITA")$med_quan08),horiz = T,beside=F,col=viridis(4),names.arg = c("Italy"))
mtext("e",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
mtext("USD billion",side =1, line =1,outer=T,cex=0.8)
dev.off()

pdf("figure_S2_zenodo.pdf",6,3.5)
layout(matrix(c(1,1,1,1,2,3,4,5),nrow = 4, ncol = 2, byrow = TRUE))
par(mar=c(2,3,.5,.1),oma=c(2,0,0,1),xpd=T)
barplot(as.matrix(sensm12),horiz = T,beside=F,col=viridis(4),xlim=c(0,350),names.arg = c("USA","Europe"))
mtext("a",font=2, side = 3, adj=-.06,lin=-0.4,cex=0.85)
#text(x=corn[1]+.01,y=corn[4]-.01,"a",font=2)
legend("topright",legend = c("Top 1% wealth owners","Next 9%","Middle 40%","Bottom 50%"),
       pch=15, lty=0, col=viridis(4)[4:1], bty="n",pt.cex=rep(2,4),x.intersp=0.9)
barplot(as.matrix(filter(sens,iso3 == "GBR")$med_quan12),horiz = T,beside=F,col=viridis(4),names.arg = c("UK"))
mtext("b",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
barplot(as.matrix(filter(sens,iso3 == "FRA")$med_quan12),horiz = T,beside=F,col=viridis(4),names.arg = c("France"))
mtext("c",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
barplot(as.matrix(filter(sens,iso3 == "DEU")$med_quan12),horiz = T,beside=F,col=viridis(4),names.arg = c("Germany"))
mtext("d",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
barplot(as.matrix(filter(sens,iso3 == "ITA")$med_quan12),horiz = T,beside=F,col=viridis(4),names.arg = c("Italy"))
mtext("e",font=2, side = 3, adj=-.13,lin=-0.4,cex=0.85)
mtext("USD billion",side =1, line =1,outer=T,cex=0.8)
dev.off()



