# Code for Figures S5a in
# Potential pension fund losses should not deter high-income countries from bold climate action
# https://doi.org/10.1016/j.joule.2023.05.023
# by Gregor Semieniuk, Lucas Chancel and Eulalie Saïsset

# load packages
library(tidyverse)
library(viridis)
options(scipen=999)

# set your working directory
setwd( "YOUR DIRECTORY" )

# read data
all <- read_csv("figureS5b_data.csv")

# format data for plotting and set some plotting parameters
spreader <- c(0.955,1.135,0.865,1.045)
all <- all %>% add_column(ctr = c(c(spreader+.3,spreader+2,spreader+3.7)-0.5,
                   c(spreader+.3,spreader+2,spreader+3.7)+5,
                   c(spreader+.3,spreader+2,spreader+3.7)+10.5,
                   c(spreader+.3,spreader+2,spreader+3.7)+16))
msrs <- unique(all$measure)
ctr<-0.7
ind<-0.66
alls <- all %>% group_by(iso2,ID) %>% summarize(wel = mean(perperson),pos = mean(ctr))
crs <- unique(all$iso2)

pdf("figure_S5b_zenodo.pdf",17.2/2.54,17.2/2.54*(3.9/6.6))
par(mar=c(2.3,3.5,.2,.1),xpd=F)
plot(all$ctr,all$ScenA,xlim=c(1,21),ann=F,xaxt="n",yaxt="n",ylim=c(0,0.065 ),bty="n")#,col="white")
for (i in c(0.005,0.01,0.02,0.04,0.06)) {abline(h=i,lty=3,col="lightgrey")}
par(xpd=T)
#points(all$ctr,all$value)

for (i in 1:4) {
  points(filter(all,measure==msrs[i])$ctr,filter(all,measure==msrs[i])$ScenA,col=viridis(4)[5-i],pch=19,cex=.9)
}
par(xpd=F)
abline(v=5.25,lty=2)
abline(v=5.25+5.5,lty=2)
abline(v=5.25+11,lty=2)
axis(2,at=c(0.005,0.01,0.02,0.04,0.06),labels=paste0(c(0.5,1,2,4,6),"%"),las=2,hadj=0.7,tcl=-0.36,cex.axis=0.8)
par(xpd=T)
mtext("b",font=2, side = 3, adj=-.1,lin=-.8,cex=0.95)
mtext("Bottom 50%",side=3,line=-.85,adj=0.005,cex=0.8)
mtext("Middle 40%",side=3,line=-.85,at=6.7,cex=0.8)
mtext("Next 9%",side=3,line=-.85,at=11.8,cex=0.8)
mtext("Top 1%",side=3,line=-.85,at=17.22,cex=0.8)
axis(1,at=c(1.3,3,4.7)-0.5,labels=c("WID","DFA","DFAnodur"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
axis(1,at=c(1.3,3,4.7)+5,labels=c("WID","DFA","DFAnodur"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
axis(1,at=c(1.3,3,4.7)+10.5,labels=c("WID","DFA","DFAnodur"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
axis(1,at=c(1.3,3,4.7)+16,labels=c("WID","DFA","DFAnodur"),cex.axis=ctr,tcl=-0.4,padj=-1.7)
mtext("Stranded assets as a share of net wealth",side=2,line=2.7,cex=0.8)
legend(11.53,0.0585,legend=c("Severe loss","Medium (quota) loss","Medium (Fig. 1) loss","Benign loss"),pch=c(19,19,19,19),col=c(viridis(4)[1:4]),box.col = "white",pt.cex=c(1.25,1.25,.9,1.25,1.25,.9),cex=0.78,bg="white",ncol=2)
text(-1.14,-0.0086,"Per adult net\nwealth in $:",cex=ind)
for(i in crs) {
  for(j in 1:2) {
    text(filter(alls,iso2==i & ID == j)$pos,-.01,paste0(round(filter(alls,iso2==i & ID == j)$wel/1e3,0),"k"),cex=ind)}}
for(i in crs) {
  for(j in 3:4) {
    text(filter(alls,iso2==i & ID == j)$pos,-0.01,paste0(round(filter(alls,iso2==i & ID == j)$wel/1e6,1),"m"),cex=ind)}}
dev.off()
